@@ -9,14 +9,18 @@ OC.L10N.register(
     "Missing a temporary folder" : "Բացակայում է ժամանակավոր պանակը",
     "Could not write file to disk" : "Չհաջողվեց գրառել նիշքը սկավառակի վրա",
     "A PHP extension stopped the file upload" : "PHP֊ի ընդլայնումն կանգնեցրեց նիշքի վերբեռնումը",
+    "File not found" : "Նիշքը չգտնվեց",
     "Translate" : "Թարգմանել",
+    "Copy link" : "Պատճենել հղումը",
     "guest" : "հյուր",
     "Saved" : "Պահված",
+    "Link" : "Հղում",
     "Cancel" : "չեղարկել",
     "URL" : "URL",
+    "Upload" : "Բեռնել",
     "Edit" : "մշակել",
     "Source code" : "ծրագրի կոդը",
-    "Info" : "Info",
-    "Warning" : "Զգուշացում"
+    "Details" : "Մանրամասներ",
+    "Choose" : "Ընտրել"
 },
 "nplurals=2; plural=(n != 1);");
